from PIL import Image

class ImageProcessingUtils:
    @staticmethod
    def load_image(file_path):
        """
        Load an image from the specified file path.

        Parameters:
        - file_path (str): Path to the image file.

        Returns:
        - Image object: Loaded image.
        """
        return Image.open(file_path)

    @staticmethod
    def resize_image(image, size):
        """
        Resize the input image to the specified size.

        Parameters:
        - image (Image object): Input image.
        - size (tuple): Target size (width, height).

        Returns:
        - Image object: Resized image.
        """
        return image.resize(size)

    @staticmethod
    def convert_to_grayscale(image):
        """
        Convert the input image to grayscale.

        Parameters:
        - image (Image object): Input image.

        Returns:
        - Image object: Grayscale image.
        """
        return image.convert("L")

    @staticmethod
    def crop_image(image, box):
        """
        Crop the input image using the specified bounding box.

        Parameters:
        - image (Image object): Input image.
        - box (tuple): Bounding box coordinates (left, upper, right, lower).

        Returns:
        - Image object: Cropped image.
        """
        return image.crop(box)

